# IODE

`IODE` is the French acronym for `Intégrateur d'Outils de Développements Économétriques` (Integrated Tools for Econometric Developments).

Originally designed at the `Federal Planning Bureau` in Brussels by econometricians and mathematicians, this software integrates all the 
functionalities required for the construction and the handling of econometric models and for the management of statistical series.

## Main functionalities :

 - construction, analysis and handling of time series of various periodicities
 - econometric language (LEC) to shorten the formula text
 - creation and estimation of (blocks of) equations
 - translation of data to and from external data
 - definition of tables and graphs to produce analytical results (comparison of scenarios…) and reporting facilities
 - model simulation and goal seeking algorithms
 - scripting language
 - export of tables and graphs towards word processors and numerous file formats

## Installation

Follow instructions on the [documentation](https://iode.readthedocs.io/en/stable/install.html) page.

## Documentation
https://iode.readthedocs.io/en/stable

## Support
"Alix Damman" <ald@plan.be>, "Yannick Van den Abbeel" <yvda@plan.be>
